#
# spec file for package python3-Beaker
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-Beaker
Version:        1.7.0
Release:        5.2
Url:            http://beaker.rtfd.org/
Summary:        A Session and Caching library with WSGI Middleware
License:        BSD-3-Clause
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/B/Beaker/Beaker-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildArch:      noarch

%description
Beaker is a web session and general caching library that includes WSGI 
middleware for use in web applications.

As a general caching library, Beaker can handle storing for various times
any Python object that can be pickled with optional back-ends on a 
fine-grained basis.

Beaker was built largely on the code from MyghtyUtils, then refactored and
extended with database support.

Beaker includes Cache and Session WSGI middleware to ease integration with
WSGI capable frameworks, and is automatically used by Pylons.

Features:

* Fast, robust performance
* Multiple reader/single writer lock system to avoid duplicate simultaneous
  cache creation
* Cache back-ends include dbm, file, memory, memcached, and database (Using
  SQLAlchemy for multiple-db vendor support)
* Signed cookie's to prevent session hijacking/spoofing
* Cookie-only sessions to remove the need for a db or file backend (ideal
  for clustered systems)
* Extensible Container object to support new back-ends
* Cache's can be divided into namespaces (to represent templates, objects,
  etc.) then keyed for different copies
* Create functions for automatic call-backs to create new cache copies after
  expiration
* Fine-grained toggling of back-ends, keys, and expiration per Cache object

%prep
%setup -q -n Beaker-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
%fdupes %buildroot/%_prefix

%files
%defattr(-,root,root,-)
%doc README.rst
%{python3_sitelib}/beaker/
%{python3_sitelib}/Beaker-%{version}-py%{py3_ver}.egg-info

%changelog
* Sat Apr 25 2015 benoit.monin@gmx.fr
- add fdupes as BuildRequires and call it after install
- switch from distribute to setuptools
- do not delete the first line of pbkdf2.py: fixed upstream
* Sat Apr 25 2015 arun@gmx.de
- specfile:
  * removed python3 and 2to3 requirements
  * added REAMDE.rst, removed CHANGELOG LICENSE (not in tar-ball anymore)
- update to version 1.7.0:
  * Beaker no longer supports python 2.4 and 2.5
  * Beaker now supports Python 2.6, 2.7, 3.2, 3.3, 3.4 without 2to3
    usage
  * Fixed Encrypted Cookie Session on Python3 #57
  * New pbkdf2 mobule working on Python3 #21
  * Fixed Test suite on Python 3.3 #53, #51
- changes from version 1.6.5:
  * @cached decorator now keeps docstring of decorated method.
  * Fix crash when Session accessed_time is not available, this
    happened when session encrypt_key was changed.
  * Fix cache regions not providing a default key length even though
    this was required and examples in the doc didn’t provide it.
  * Fix crash when cache expire wasn’t an int, this happened when
    caching options were loaded from a config file.
* Sat Jan 10 2015 arun@gmx.de
- specfile:
  * update copyright year
  * remove python(abi) requirement
* Thu Nov 22 2012 toddrme2178@gmail.com
- Remove openSUSE 11.4 spec file workarounds
* Sat Sep 22 2012 os-dev@jacraig.com
- Update to 1.6.4:
  * Warning: Session hashing for encrypted sessions using PyCrypto has
    changed. This will result in sessions being invalidated upon upgrading
    if PyCrypto is used.
  * Fix bug with key_length not being coerced to a int for comparison.
  * Fix bug with cookie invalidation not clearing the cookie data.
  * Added ability to pass in cookie_path for the Session.
  * Add NSS crypto support to Beaker.
  * Fix security bug with pycrypto not securing data such that an attacker
    could possibly determine parts of the encrypted payload. See CVE-2012-3458
    <http://web.nvd.nist.gov/view/vuln/detail?vulnId=CVE-2012-3458>.
  * Add ability to specify schema for database-backed sessions.
  * Fix issue with long key names in memcached backend.
- Fix sed script so it removes the shebang instead of inserting "d" throughout
  the pbkdf2.py file.
- Test suite now succeeds (for Python 2 package) but didn't add it to build
  because it takes too long.
- Update URL to what is given in setup.py.
* Thu Sep  6 2012 toddrme2178@gmail.com
- Restore BuildRequires: python3  This package depends on hash
  algorithms that are only available if python3 is installed,
  python3-devel will not pull them in.  Building will fail if
  BuildRequires: python3 is removed.
* Fri May 25 2012 toddrme2178@gmail.com
- Fix building on openSUSE 11.4
- spec file cleanups
* Wed May 23 2012 highwaystar.ru@gmail.com
- python3 package added
